==> koin-0.13.1.tar.gz: test/core/definition_created_at_star_test.dart <==
import 'package:koin/koin.dart';
import 'package:koin/src/core/context/context_functions.dart';
import 'package:koin/src/core/instance/single_instance_factory.dart';
import 'package:test/test.dart';

import '../components.dart';
import '../extensions/koin_application_ext.dart';

void main() {
  test('is declared as created at start', () {
    var app = koinApplication((app) {
      app.module(module()
        ..single<ComponentA>((s) => ComponentA(), createdAtStart: true));
    });

    var defA = app.getBeanDefinition(ComponentA);
    expect(true, defA.options.isCreatedAtStart);

    var instanceFactory = app.getInstanceFactory(ComponentA);
    expect(false, (instanceFactory as SingleInstanceFactory).isCreated());
  });

  test('is created at start', () {
    var app = startKoin((app) {
      app.module((module()
        ..single<ComponentA>((s) => ComponentA(), createdAtStart: true)));
    });

    var defA = app.getBeanDefinition(ComponentA);
    expect(true, defA.options.isCreatedAtStart);
    var instanceFactory = app.getInstanceFactory(ComponentA);
    expect(true, (instanceFactory as SingleInstanceFactory).isCreated());

    stopKoin();
  });

  test('factory is not created at start', () {
    var app = koinApplication((app) {
      app.module(module()..single<ComponentA>((s) => ComponentA()));
    });

    var defA = app.getBeanDefinition(ComponentA);
    expect(false, defA.options.isCreatedAtStart);

    var instanceFactory = app.getInstanceFactory(ComponentA);
    expect(false, (instanceFactory as SingleInstanceFactory).isCreated());

    app.close();
  });
}

==> koin-0.14.1.tar.gz: test/core/definition_created_at_star_test.dart <==
import 'package:koin/koin.dart';
import 'package:koin/src/context/context_functions.dart';
import 'package:koin/src/instance/single_instance_factory.dart';
import 'package:test/test.dart';

import '../components.dart';
import '../extensions/koin_application_ext.dart';

void main() {
  test('is declared as created at start', () {
    var app = koinApplication((app) {
      app.module(module()
        ..single<ComponentA>((s) => ComponentA(), createdAtStart: true));
    });

    var defA = app.getBeanDefinition(ComponentA);
    expect(true, defA.options.isCreatedAtStart);

    var instanceFactory = app.getInstanceFactory(ComponentA);
    expect(false, (instanceFactory as SingleInstanceFactory).created);
  });

  test('is created at start', () {
    var app = startKoin((app) {
      app.module((module()
        ..single<ComponentA>((s) => ComponentA(), createdAtStart: true)));
    });

    var defA = app.getBeanDefinition(ComponentA);
    expect(true, defA.options.isCreatedAtStart);
    var instanceFactory = app.getInstanceFactory(ComponentA);
    expect(true, (instanceFactory as SingleInstanceFactory).created);

    stopKoin();
  });

  test('factory is not created at start', () {
    var app = koinApplication((app) {
      app.module(module()..single<ComponentA>((s) => ComponentA()));
    });

    var defA = app.getBeanDefinition(ComponentA);
    expect(false, defA.options.isCreatedAtStart);

    var instanceFactory = app.getInstanceFactory(ComponentA);
    expect(false, (instanceFactory as SingleInstanceFactory).created);

    app.close();
  });
}
